# Django L10N extensions
Django L10N extensions adds some useful L10N extensions to the Django framework

The project in maintained on [github](https://github.com/ceasaro/django-l10n-extensions)

[Read the docs](http://django-l10n-extensions.readthedocs.io)